@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
 import importlib
 import inspect
 import subprocess
 
 from logzero import logger
+
 try:
     import importlib.metadata as importlib_metadata
 except ImportError:
@@ -19,22 +19,26 @@ def install(package_name: str):
     Use pip to download and install the `package_name` to the current Python
     environment. Pip can detect it is already installed.
     """
-    logger.info("Attempting to download and install package '{p}'".format(
-        p=package_name))
+    logger.info(f"Attempting to download and install package '{package_name}'")
 
     process = subprocess.run(
-        ["pip", "install", "-U", package_name], stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE)
+        ["pip", "install", "-U", package_name],
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+    )
 
-    stdout = process.stdout.decode('utf-8')
-    stderr = process.stderr.decode('utf-8')
+    stdout = process.stdout.decode("utf-8")
+    stderr = process.stderr.decode("utf-8")
     logger.debug(stdout)
 
     if process.returncode != 0:
-        msg = "failed to install `{p}`".format(p=package_name)
+        msg = f"failed to install `{package_name}`"
         logger.debug(
-            msg + "\n=================\n{o}\n=================\n{e}\n".format(
-                o=stdout, e=stderr))
+            msg
+            + "\n=================\n{o}\n=================\n{e}\n".format(
+                o=stdout, e=stderr
+            )
+        )
         raise DiscoveryFailed(msg)
 
     logger.info("Package downloaded and installed in current environment")
@@ -48,8 +52,7 @@ def load_package(package_name: str) -> object:
     try:
         package = importlib.import_module(name)
     except ImportError:
-        raise DiscoveryFailed(
-            "could not load Python module '{name}'".format(name=name))
+        raise DiscoveryFailed(f"could not load Python module '{name}'")
 
     return package
 
@@ -60,12 +63,14 @@ def get_discover_function(package: object):
     """
     funcs = inspect.getmembers(package, inspect.isfunction)
     for (name, value) in funcs:
-        if name == 'discover':
+        if name == "discover":
             return value
 
     raise DiscoveryFailed(
         "package '{name}' does not export a `discover` function".format(
-            name=package.__name__))
+            name=package.__name__
+        )
+    )
 
 
 ###############################################################################
@@ -76,9 +81,10 @@ class PathDistribution(importlib_metadata.PathDistribution):
     Extends the class for easier retrieval of top-level package names
     for a distribution installed package
     """
+
     @property
     def top_level(self):
-        text = self.read_text('top_level.txt')
+        text = self.read_text("top_level.txt")
         return text and text.splitlines()
 
 
@@ -98,16 +104,15 @@ def get_importname_from_package(package_name: str) -> str:
     try:
         dist = importlib_metadata.distribution(package_name)
     except importlib_metadata.PackageNotFoundError:
-        raise DiscoveryFailed(
-            "Package {p} not found ".format(p=package_name)
-        )
+        raise DiscoveryFailed(f"Package {package_name} not found ")
 
     try:
         packages = dist.top_level
     except FileNotFoundError:
         raise DiscoveryFailed(
             "failed to load package {p} metadata. "
-            "Was the package installed properly?".format(p=package_name))
+            "Was the package installed properly?".format(p=package_name)
+        )
 
     if len(packages) > 1:
         raise DiscoveryFailed(
